==> java-cxf-spring-server-generator-0.13.2.tgz: package/test-output/junit5/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/Verification.java <==
package com.example.model;

/**
 * Model for Verification
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-05T19:55:16.329Z")
@io.swagger.annotations.ApiModel(value = "Verification", description = "Model for Verification")
@javax.xml.bind.annotation.XmlRootElement(name = "Verification")
public class Verification implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private com.example.model.Components components = null;
	private java.lang.String name = null;
	private java.lang.String points = null;
	private java.lang.String results = null;
	private java.lang.String searchName = null;
	private java.lang.String value = null;
	
	/**
	 * Model for Components
	 */
	public Verification components(com.example.model.Components components) {
		setComponents(components);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(required = true, value = "Model for Components")
	@com.fasterxml.jackson.annotation.JsonProperty("components")
	@javax.validation.Valid
	@javax.validation.constraints.NotNull
	public com.example.model.Components getComponents() {
		return this.components;
	}
	public void setComponents(com.example.model.Components components) {
		this.components = components;
	}
	
	/**
	 */
	public Verification name(java.lang.String name) {
		setName(name);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("name")
	public java.lang.String getName() {
		return this.name;
	}
	public void setName(java.lang.String name) {
		this.name = name;
	}
	
	/**
	 */
	public Verification points(java.lang.String points) {
		setPoints(points);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("points")
	public java.lang.String getPoints() {
		return this.points;
	}
	public void setPoints(java.lang.String points) {
		this.points = points;
	}
	
	/**
	 */
	public Verification results(java.lang.String results) {
		setResults(results);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("results")
	public java.lang.String getResults() {
		return this.results;
	}
	public void setResults(java.lang.String results) {
		this.results = results;
	}
	
	/**
	 */
	public Verification searchName(java.lang.String searchName) {
		setSearchName(searchName);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("searchName")
	public java.lang.String getSearchName() {
		return this.searchName;
	}
	public void setSearchName(java.lang.String searchName) {
		this.searchName = searchName;
	}
	
	/**
	 */
	public Verification value(java.lang.String value) {
		setValue(value);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("value")
	public java.lang.String getValue() {
		return this.value;
	}
	public void setValue(java.lang.String value) {
		this.value = value;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		Verification verification = (Verification) o;
		return java.util.Objects.equals(this.components, verification.components)
				&& java.util.Objects.equals(this.name, verification.name)
				&& java.util.Objects.equals(this.points, verification.points)
				&& java.util.Objects.equals(this.results, verification.results)
				&& java.util.Objects.equals(this.searchName, verification.searchName)
				&& java.util.Objects.equals(this.value, verification.value);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.components, this.name, this.points, this.results, this.searchName, this.value);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class Verification {\n");
		
		sb.append("    components: ").append(toIndentedString(this.components)).append("\n");
		sb.append("    name: ").append(toIndentedString(this.name)).append("\n");
		sb.append("    points: ").append(toIndentedString(this.points)).append("\n");
		sb.append("    results: ").append(toIndentedString(this.results)).append("\n");
		sb.append("    searchName: ").append(toIndentedString(this.searchName)).append("\n");
		sb.append("    value: ").append(toIndentedString(this.value)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}

==> java-cxf-spring-server-generator-0.14.0.tgz: package/test-output/junit5/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/Verification.java <==
package com.example.model;

/**
 * Model for Verification
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-09T22:14:49.443Z")
@io.swagger.v3.oas.annotations.media.Schema(name = "Verification", description = "Model for Verification")
@javax.xml.bind.annotation.XmlRootElement(name = "Verification")
public class Verification implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private com.example.model.Components components = null;
	private java.lang.String name = null;
	private java.lang.String points = null;
	private java.lang.String results = null;
	private java.lang.String searchName = null;
	private java.lang.String value = null;
	
	/**
	 * Model for Components
	 */
	public Verification components(com.example.model.Components components) {
		setComponents(components);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(required = true, name = "components", description = "Model for Components")
	@com.fasterxml.jackson.annotation.JsonProperty("components")
	@javax.validation.Valid
	@javax.validation.constraints.NotNull
	public com.example.model.Components getComponents() {
		return this.components;
	}
	public void setComponents(com.example.model.Components components) {
		this.components = components;
	}
	
	/**
	 */
	public Verification name(java.lang.String name) {
		setName(name);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "name")
	@com.fasterxml.jackson.annotation.JsonProperty("name")
	public java.lang.String getName() {
		return this.name;
	}
	public void setName(java.lang.String name) {
		this.name = name;
	}
	
	/**
	 */
	public Verification points(java.lang.String points) {
		setPoints(points);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "points")
	@com.fasterxml.jackson.annotation.JsonProperty("points")
	public java.lang.String getPoints() {
		return this.points;
	}
	public void setPoints(java.lang.String points) {
		this.points = points;
	}
	
	/**
	 */
	public Verification results(java.lang.String results) {
		setResults(results);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "results")
	@com.fasterxml.jackson.annotation.JsonProperty("results")
	public java.lang.String getResults() {
		return this.results;
	}
	public void setResults(java.lang.String results) {
		this.results = results;
	}
	
	/**
	 */
	public Verification searchName(java.lang.String searchName) {
		setSearchName(searchName);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "searchName")
	@com.fasterxml.jackson.annotation.JsonProperty("searchName")
	public java.lang.String getSearchName() {
		return this.searchName;
	}
	public void setSearchName(java.lang.String searchName) {
		this.searchName = searchName;
	}
	
	/**
	 */
	public Verification value(java.lang.String value) {
		setValue(value);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "value")
	@com.fasterxml.jackson.annotation.JsonProperty("value")
	public java.lang.String getValue() {
		return this.value;
	}
	public void setValue(java.lang.String value) {
		this.value = value;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		Verification verification = (Verification) o;
		return java.util.Objects.equals(this.components, verification.components)
				&& java.util.Objects.equals(this.name, verification.name)
				&& java.util.Objects.equals(this.points, verification.points)
				&& java.util.Objects.equals(this.results, verification.results)
				&& java.util.Objects.equals(this.searchName, verification.searchName)
				&& java.util.Objects.equals(this.value, verification.value);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.components, this.name, this.points, this.results, this.searchName, this.value);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class Verification {\n");
		
		sb.append("    components: ").append(toIndentedString(this.components)).append("\n");
		sb.append("    name: ").append(toIndentedString(this.name)).append("\n");
		sb.append("    points: ").append(toIndentedString(this.points)).append("\n");
		sb.append("    results: ").append(toIndentedString(this.results)).append("\n");
		sb.append("    searchName: ").append(toIndentedString(this.searchName)).append("\n");
		sb.append("    value: ").append(toIndentedString(this.value)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}
